pub struct AsyncRtm<K, V, C, P, S>where
S: AsyncSpawner,{ /* private fields */ }Expand description
AsyncRtm is a read-only transaction manager.
It is created by calling AsyncTm::read,
the read transaction will automatically notify the transaction manager when it
is dropped. So, the end user doesn’t need to call any cleanup function, but must
hold this struct in their final read transaction implementation.
Implementations